from aio_client.provider.api import PostProviderRequest
from aio_client.provider.api import push_request

from concentrator.smev3_v321.base.constants import SUCCESS_MESSAGE
from concentrator.smev3_v321.base.utils import BaseExecutor
from concentrator.smev3_v321.base.utils import SMEV3Response
from concentrator.smev3_v321.base.utils import render_type2xml
from concentrator.smev3_v321.service_types import kinder_conc

from .application import ApplicationManager


class ApplicationRequestExecutor(BaseExecutor):
    """Исполнитель сервиса ApplicationRequest."""

    name_service = 'ApplicationRequest'
    type_service = kinder_conc.ApplicationType

    @classmethod
    def process(cls, message, request_body):

        attachments = message['attachments']

        response_body = render_type2xml(
            cls.get_response(request_body.ApplicationRequest, attachments),
            name_type='FormDataResponse')

        response = push_request(PostProviderRequest(
            origin_message_id=message['origin_message_id'],
            body=response_body,
            message_type=message['message_type'],
            attachments=None,
            content_failure_code=None,
            replay_to=message['replay_to'],
            is_test_message=message['is_test_message']
        ))

        return SMEV3Response(
            response,
            {
                'method_name': cls.name_service,
                'response': response_body,
                'result': SUCCESS_MESSAGE
            })

    @classmethod
    def get_response(cls, application_request, attachments):
        """Формирует и возвращает ответ.

        :param application_request: Данные заявления
        :type application_request: ApplicationType
        :param attachments: Прикрепленные файлы (формат JSON)
        :type attachments: Union[list, str, bytearray, bytes]

        :return: Ответ
        :rtype: FormDataResponseType
        """

        result = ApplicationManager(application_request, attachments).run()

        response = kinder_conc.FormDataResponseType(
            changeOrderInfo=kinder_conc.changeOrderInfoType(
                orderId=kinder_conc.orderIdType(result.order_id),
                statusCode=kinder_conc.statusCodeType(
                    result.org_code, result.tech_code),
                comment=result.comment))

        return response
