from django.apps import AppConfig
from django.apps.registry import apps


class Smev3Config(AppConfig):

    name = 'concentrator.smev3_v321'
    label = 'smev3_v321'
    verbose_name = 'СМЭВ 3'

    def ready(self):
        # Данные из контингента тянутся в сервисах смэв3
        if not apps.is_installed('kinder.plugins.contingent'):
            raise RuntimeError('Contingent plugin must be installed')
        # Иначе не видят таски
        import concentrator.smev3_v321.base.tasks
        import concentrator.smev3_v321.esnsi.tasks

        from .base.utils import SMEV3RepositoryExecutors
        from .application_request.helpers import ApplicationRequestExecutor
        from .get_application_admission_request.helpers import (
            GetApplicationAdmissionRequestExecutor)
        from .application_rejection_request.helpers import (
            ApplicationRejectionRequestExecutor)
        from concentrator.smev3_v321.get_application_queue.helpers import (
            GetApplicationQueueRequestExecutor
        )
        from concentrator.smev3_v321.get_application_request.helpers import (
            GetApplicationRequestExecutor)
        from .cancel_request.helpers import CancelRequestExecutor

        config = [
            ApplicationRequestExecutor,
            GetApplicationAdmissionRequestExecutor,
            ApplicationRejectionRequestExecutor,
            GetApplicationQueueRequestExecutor,
            GetApplicationRequestExecutor,
            CancelRequestExecutor,
        ]

        SMEV3RepositoryExecutors.set_up(config)
