from datetime import datetime

from m3.actions import ApplicationLogicException

from concentrator.smev3_v321.esnsi.builders import UpdateClassifierRequestBuilder
from concentrator.smev3_v321.esnsi.settings import UPDATE_CLASSIFIER_REQUEST_MSG_TYPE
from concentrator.smev3_v321.models import UpdateClassifierRequest
from kinder.webservice.smev3.tasks.consumer import SendingAsConsumerTask
from kinder.webservice.smev3.utils.error_logging import BaseExceptionLogger


class _ApplicationErrorLogger(BaseExceptionLogger):
    """
    Логируем ошибки приложения
    """
    def get_message(self):
        return (
            'Ошибка приложения - %s' % str(self.exc))


class EsnsiSendingTask(SendingAsConsumerTask):
    """
    Задача отправки запросов к ЕСНСИ
    """
    description = 'Отправка запросов к ЕСНСИ'
    model = UpdateClassifierRequest
    message_type = UPDATE_CLASSIFIER_REQUEST_MSG_TYPE
    request_builder = UpdateClassifierRequestBuilder
    catchable_exceptions = {
        **SendingAsConsumerTask.catchable_exceptions,
        ApplicationLogicException: _ApplicationErrorLogger
    }

    def send(self, message):
        super(EsnsiSendingTask, self).send(message)
        message.request.request_sent = datetime.now()
        message.request.save()
